package websocket

import (
	"github.com/gorilla/websocket"
	"net/http"
	"time"

	"git.smsvc.net/pomodoro/GoTomato/internal/helper"
	"git.smsvc.net/pomodoro/GoTomato/pkg/models"
)

// Upgrade HTTP requests to WebSocket connections
var upgrader = websocket.Upgrader{
	CheckOrigin: func(r *http.Request) bool { return true },
}

// Upgrades HTTP requests to WebSocket connections and manages the client lifecycle
func HandleConnection(w http.ResponseWriter, r *http.Request) {
	// Upgrade initial GET request to a WebSocket
	ws, err := upgrader.Upgrade(w, r, nil)
	if err != nil {
		helper.Logger.Error("WebSocket upgrade error:", "msg", err)
		return
	}
	defer ws.Close()

	// Register the new client
	client := models.WebsocketClient{
		Conn:     ws,
		LastPong: time.Now(),
		RealIP:   r.RemoteAddr,
	}
	client.Conn.SetPongHandler(func(s string) error {
		client.LastPong = time.Now()
		return nil
	})

	mu.Lock()
	Clients[ws.LocalAddr()] = &client
	mu.Unlock()

	helper.Logger.Info("Client connected", "host", client.RealIP, "clients", len(Clients))

	// Listen for commands from the connected client
	handleClientCommands(client)
}
